| Title: | An NBA Jersey Palette Generator |
|---|---|
| Description: | Palettes generated from NBA jersey colorways. |
| Authors: | Murray Josh [aut, cre] |
| Maintainer: | Murray Josh <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-05-20 09:45:29 UTC |
| Source: | https://github.com/murrayjw/nbapalettes |
Palette options Generate a tibble of with palette options
available_palettes(team = "all")available_palettes(team = "all")
team |
return all available colors for a given team. Default is all available teams |
A tibble containing the palette options for a given NBA team.
available_palettes()#' available_palettes('raptors')#' available_palettes('heat')available_palettes()#' available_palettes('raptors')#' available_palettes('heat')
Color palettes associated with a large variety of NBA team jerseys.
nba_palette(name, n, type = c("discrete", "continuous"))nba_palette(name, n, type = c("discrete", "continuous"))
name |
Name of desired palette. use 'available_palettes()' to see which options are available |
n |
Number of colors desired. Most palettes contain 3-5 colors although some contain as many as 8-10. All color schemes are derived from the following amazing resource: TruColor. If omitted, uses all colours. |
type |
Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colours. |
A vector of colours.
nba_palette("raptors") nba_palette("jazz_city") nba_palette("nuggets_80s") # If you need more colours than normally found in a palette, you # can use a continuous palette to interpolate between existing # colours pal <- nba_palette(n = 21, name = "grizzlies", type = "continuous") palnba_palette("raptors") nba_palette("jazz_city") nba_palette("nuggets_80s") # If you need more colours than normally found in a palette, you # can use a continuous palette to interpolate between existing # colours pal <- nba_palette(n = 21, name = "grizzlies", type = "continuous") pal
Use nba_palette to construct palettes of desired length.
nba_palettesnba_palettes
An object of class list of length 129.
A dataset containing results and total team statistics from each regular season NBA game from the 2019-2020 season. The data is can be obtained by using the 'game_logs()' function from the 'nbastatR' package
nba_results2020nba_results2020
A data frame with 2118 rows and 47 variables:
http://asbcllc.com/nbastatR/reference/game_logs.html
list of palettes from NBA jersey colorways
list of palettes from NBA jersey colorways